@@ -122,7 +122,7 @@ gail_container_get_n_children (AtkObject* obj)
   if (widget == NULL)
     return count;
 
-  children = gtk_container_children (GTK_CONTAINER(widget));
+  children = gtk_container_get_children (GTK_CONTAINER(widget));
   count = g_list_length (children);
   g_list_free (children);
 
@@ -143,7 +143,7 @@ gail_container_ref_child (AtkObject *obj,
   if (widget == NULL)
     return NULL;
 
-  children = gtk_container_children (GTK_CONTAINER(widget));
+  children = gtk_container_get_children (GTK_CONTAINER (widget));
   tmp_list = g_list_nth (children, i);
   if (!tmp_list)
     {
@@ -169,7 +169,7 @@ gail_container_add_gtk (GtkContainer       *container,
   g_object_notify (G_OBJECT (atk_child), "accessible_parent");
 
   g_list_free (gail_container->children);
-  gail_container->children = gtk_container_children (container);
+  gail_container->children = gtk_container_get_children (container);
   index = g_list_index (gail_container->children, widget);
   g_signal_emit_by_name (atk_parent, "children_changed::add", 
                          index, atk_child, NULL);
@@ -196,7 +196,7 @@ gail_container_remove_gtk (GtkContainer       *container,
 
   index = g_list_index (gail_container->children, widget);
   g_list_free (gail_container->children);
-  gail_container->children = gtk_container_children (container);
+  gail_container->children = gtk_container_get_children (container);
   g_signal_emit_by_name (atk_parent, "children_changed::remove", 
                          index, atk_child, NULL);
 
@@ -212,7 +212,7 @@ gail_container_real_initialize (AtkObject *obj,
 
   ATK_OBJECT_CLASS (parent_class)->initialize (obj, data);
 
-  container->children = gtk_container_children (GTK_CONTAINER (data));
+  container->children = gtk_container_get_children (GTK_CONTAINER (data));
 
   /*
    * We store the handler ids for these signals as some objects, e.g.
