@@ -1,5 +1,5 @@
 /* GAIL - The GNOME Accessibility Enabling Library
- * Copyright 2001 Sun Microsystems Inc.
+ * Copyright 2001, 2002, 2003 Sun Microsystems Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -159,6 +159,7 @@ gail_label_real_initialize (AtkObject *obj,
                             gpointer  data)
 {
   GtkLabel  *label;
+  GtkWidget  *widget;
   GailLabel *gail_label;
   const gchar *label_text;
 
@@ -166,8 +167,8 @@ gail_label_real_initialize (AtkObject *obj,
   
   gail_label = GAIL_LABEL (obj);
 
-  gail_label->cursor_position = -1;
-  gail_label->selection_bound = -1;
+  gail_label->cursor_position = 0;
+  gail_label->selection_bound = 0;
   
   gail_label->textutil = gail_text_util_new ();
 
@@ -179,6 +180,21 @@ gail_label_real_initialize (AtkObject *obj,
     gail_label->label_length = 0;
   else
     gail_label->label_length = g_utf8_strlen (label_text, -1);
+
+  /* 
+   * Check whether ancestor of GtkLabel is a GtkButton  and if so
+   * set accessible parent for GailLabel
+   */
+  widget = GTK_WIDGET (data);
+  while (widget != NULL)
+    {
+      widget = gtk_widget_get_parent (widget);
+      if (GTK_IS_BUTTON (widget))
+        {
+          atk_object_set_parent (obj, gtk_widget_get_accessible (widget));
+          break;
+        }
+    }
 }
 
 AtkObject* 
@@ -277,8 +293,8 @@ gail_label_real_notify_gtk (GObject           *obj,
             {
               /* GtkLabel has become non selectable */
 
-              gail_label->cursor_position = -1;
-              gail_label->selection_bound = -1;
+              gail_label->cursor_position = 0;
+              gail_label->selection_bound = 0;
               text_caret_moved = TRUE;
             }
             
@@ -769,7 +785,12 @@ gail_label_get_offset_at_point (AtkText      *text,
                                               gtk_label_get_layout (label), 
                                               x_layout, y_layout, x, y, coords);
   if (index == -1)
-    return index;  
+    {
+      if (coords == ATK_XY_WINDOW || coords == ATK_XY_SCREEN)
+        return g_utf8_strlen (label->text, -1);
+
+      return index;  
+    }
   else
     return g_utf8_pointer_to_offset (label->text, label->text + index);  
 }
@@ -824,7 +845,6 @@ gail_label_get_default_attributes (AtkText        *text)
   GtkWidget *widget;
   GtkLabel *label;
   AtkAttributeSet *at_set = NULL;
-  gboolean wrap_value;
 
   widget = GTK_ACCESSIBLE (text)->widget;
   if (widget == NULL)
@@ -855,6 +875,8 @@ gail_label_get_character_at_offset (AtkText	         *text,
 
   label = GTK_LABEL (widget);
   string = gtk_label_get_text (label);
+  if (offset >= g_utf8_strlen (string, -1))
+    return '\0';
   index = g_utf8_offset_to_pointer (string, offset);
 
   return g_utf8_get_char (index);
